﻿using System;
using System.Collections.Generic;

using IBatisNet.DataMapper;
using IBatisNet.DataMapper.Configuration;

namespace TestProject
{
    /// <summary>
    /// 샘플 DAO
    /// </summary>
    public class SampleDAO
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 매퍼 구하기 - GetMapper()

        /// <summary>
        /// 매퍼 구하기
        /// </summary>
        /// <returns>SQL 매퍼 인터페이스</returns>
        public ISqlMapper GetMapper()
        {
            DomSqlMapBuilder builder = new DomSqlMapBuilder();

            ISqlMapper mapper = builder.Configure("SqlMap.config");

            return mapper;
        }

        #endregion

        #region 샘플 리스트 구하기 - GetSampleList()

        /// <summary>
        /// 샘플 리스트 구하기
        /// </summary>
        /// <returns>샘플 리스트</returns>
        public IList<SampleModel> GetSampleList()
        {
            ISqlMapper mapper = Mapper.Instance();

            IList<SampleModel> list = mapper.QueryForList<SampleModel>("SampleDAO.GetSampleList", null);

            return list;
        }

        #endregion
        #region 샘플 삽입하기 - InsertSample(createTime, value1, value2)

        /// <summary>
        /// 샘플 삽입하기
        /// </summary>
        /// <param name="createTime">생성 시간</param>
        /// <param name="value1">값 1</param>
        /// <param name="value2">값 2</param>
        public void InsertSample(DateTime createTime, double value1, double value2)
        {
            SampleModel sample = new SampleModel();

            sample.CREATE_TIME = createTime;
            sample.VALUE1      = value1;
            sample.VALUE2      = value2;

            GetMapper().Insert("SampleDAO.InsertSample", sample);
        }

        #endregion
        #region 샘플 수정하기 - UpdateSample(id, value1)

        /// <summary>
        /// 샘플 수정하기
        /// </summary>
        /// <param name="id">ID</param>
        /// <param name="value1">값 1</param>
        /// <returns>샘플 수정 결과</returns>
        public bool UpdateSample(int id, double value1)
        {
            SampleModel sample = new SampleModel();

            sample.ID     = id;
            sample.VALUE1 = value1;

            return GetMapper().Update("SampleDAO.UpdateSample", sample) > 0 ? true : false;
        }

        #endregion
        #region 샘플 삭제하기 - DeleteSample(id)

        /// <summary>
        /// 샘플 삭제하기
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>샘플 삭제 결과</returns>
        public bool DeleteSample(int id)
        {
            SampleModel sample = new SampleModel();

            sample.ID = id;

            return GetMapper().Delete("SampleDAO.DeleteSample", sample) > 0 ? true : false;
        }

        #endregion
    }
}